@@ -251,10 +251,10 @@ class ControllerMongoDB:
         
         # source description
         reponse['source_description'] =responde_transaction['history-track'][0]['USER']['description']
-        reponse['cat_uid_def_usr'] =responde_transaction['history-track'][0]['CASE']['categorization']['category_uid']
-        reponse['subcat_uid_def_usr'] =responde_transaction['history-track'][0]['CASE']['categorization']['subcategory_uid']
-        reponse['nickname_algo'] =responde_transaction['history-track'][0]['CASE']['categorization']['description']
-        reponse['categorized'] =responde_transaction['history-track'][0]['CASE']['categorized']
-        reponse['model_classification_version'] =responde_transaction['history-track'][0]['MODEL']['model_uid']
+        # reponse['cat_uid_def_algo'] =responde_transaction['history-track'][0]['CASE']['categorization']['category_uid']
+        # reponse['subcat_uid_def_algo'] =responde_transaction['history-track'][0]['CASE']['categorization']['subcategory_uid']
+        # reponse['nickname_algo'] =responde_transaction['history-track'][0]['CASE']['categorization']['description']
+        # reponse['categorized'] =responde_transaction['history-track'][0]['CASE']['categorized']
+        # reponse['model_classification_version'] =responde_transaction['history-track'][0]['MODEL']['model_uid']
         
         return reponse
