@@ -304,7 +304,7 @@ class ControllerRedShift:
             'classified_date' : dict_values['classified_date'],
             'clean_description' : dict_values['clean_description'],
             'country_code' : dict_values['country_code'],
-            'created_holomogation_date' : dict_values['created_holomogation_date'],
+            'created_homologation_date' : dict_values['created_homologation_date'],
             'flow_type' : dict_values['flow_type'],
             'frequency_uid_collective' : dict_values['frequency_uid_def_collect'],
             'frequency_uid_custom' : dict_values['frequency_uid_def_usr'],
@@ -381,7 +381,7 @@ class ControllerRedShift:
                         classified_date,
                         clean_description,
                         country_code,
-                        created_holomogation_date,
+                        created_homologation_date,
                         flow_type,
                         frequency_uid_collective,
                         frequency_uid_custom,
@@ -575,7 +575,97 @@ class ControllerRedShift:
                             dict_values['created_at']
                             )
             cur.execute(redshift_insert_query, record_to_insert)
-            
+
+    def insert_dim_visualization(self,dict_values):
+        with self.engine.connect() as cur:
+            redshift_insert_query = '''
+                        INSERT INTO dim_visualization (
+                                transaction_uid,
+                                language_code,
+                                country_code,
+                                flow_type,
+                                message_type,
+                                validated,
+                                source_description,
+                                clean_description,
+                                is_loan_requested,
+                                is_membership,
+                                subcategory_uid,
+                                category_uid,
+                                special_moment_uid,
+                                is_essential,
+                                frequency_uid,
+                                asset_uid,
+                                person_uid,
+                                business_uid,
+                                income_source_uid,
+                                is_loan_received,
+                                description,
+                                original_created_date,
+                                created_homologation_date,
+                                classified_date,
+                                validated_date,
+                                updated_date
+                                )
+                        VALUES (
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s,
+                                %s
+                                )
+                                    '''
+            record_to_insert = (
+                            dict_values['transaction_uid'],
+                            dict_values['language_code'],
+                            dict_values['country_code'],
+                            dict_values['flow_type'],
+                            dict_values['message_type'],
+                            dict_values['validated'],
+                            dict_values['source_description'],
+                            dict_values['clean_description'],
+                            dict_values['is_loan_requested'],
+                            dict_values['is_membership'],
+                            dict_values['subcategory_uid'],
+                            dict_values['category_uid'],
+                            dict_values['special_moment_uid'],
+                            dict_values['is_essential'],
+                            dict_values['frequency_uid'],
+                            dict_values['asset_uid'],
+                            dict_values['person_uid'],
+                            dict_values['business_uid'],
+                            dict_values['income_source_uid'],
+                            dict_values['is_loan_received'],
+                            dict_values['description'],
+                            dict_values['original_created_date'],
+                            dict_values['created_at_homologation'],
+                            dict_values['classified_at'],
+                            dict_values['created_at'],
+                            dict_values['updated_at']
+                            )
+            cur.execute(redshift_insert_query, record_to_insert)
+
     def insert_fact_transactions(self,dict_values):
         with self.engine.connect() as cur:
             redshift_insert_query = '''
@@ -598,6 +688,29 @@ class ControllerRedShift:
                         dict_values['currency']
                                 )
             cur.execute(redshift_insert_query, record_to_insert)
+
+    def insert_fact_visualization(self,dict_values):
+        with self.engine.connect() as cur:
+            redshift_insert_query = '''
+                        INSERT INTO fact_visualization (
+                                                transaction_date,
+                                                transaction_uid,
+                                                user_uid,
+                                                account_uid,
+                                                amount,
+                                                currency
+                                                )
+                        VALUES (%s,%s,%s,%s,%s,%s)
+                                    '''
+            record_to_insert = (
+                        dict_values['transaction_date'],
+                        dict_values['transaction_uid'],
+                        dict_values['user_uid'],
+                        dict_values['account_uid'],
+                        dict_values['amount'],
+                        dict_values['currency']
+                                )
+            cur.execute(redshift_insert_query, record_to_insert)
             
     def insert_(self):
         """
