@@ -21,7 +21,7 @@ class TypeTransEnrichment:
             'user_uid': None,
             # delegar a MS-Report
             'transaction_uid': None,
-            'message-type' : None,
+            'message-type':None,
             'offset': None,
             'data': None,
             'dynamo': None
@@ -226,12 +226,12 @@ class CategorizationObject:
             "frequency_uid": None, # ID de la frecuencia asociada a la transacción
             "is_essential": None, # True| False  si el gasto es escencial
             "is_membership": None, # True| False si el gasto pertence a un menbresía
-            "income_source_uid" : None,
-            "is_loan_received" : None,
+            "income_source_uid":None,
+            "is_loan_received":None,
             "is_loan_requested": None,
-            "collective_subcategory_uid" : None,
-            "collective_description" : None,
-            "collective_is_essential" : None,
+            "collective_subcategory_uid":None,
+            "collective_description":None,
+            "collective_is_essential":None,
             "collective_is_membership" : None
 			}
 
@@ -334,7 +334,7 @@ class DimTransactions:
         "business_uid_collective": None,
         "special_moment_uid_collective": None,
         "original_created_date": None,
-        "created_holomogation_date": None,
+        "created_homologation_date": None,
         "classified_date": None,
         "validated_date": None,
         "updated_date": None,
@@ -350,26 +350,27 @@ class DimAccount:
     """
     def __init__(self) -> None:
         self.Item = {
-    "account_uid" : None,
-    "bank_name" : None,
-    "account_type" : None,
-    "bank_type" : None,
-    "created_at" : None,
-    "updated_at" : None,
+    "account_uid":None,
+    "bank_name":None,
+    "account_type":None,
+    "bank_type":None,
+    "created_at":None,
+    "updated_at":None,
     "deleted_at" : None
     }
     def get(self):
         return self.Item
 
+# fix
 class DimUser:
     """
     """
     def __init__(self) -> None:
         self.Item = {
-    "user_uid" : None,
-    # "postcode" : None,
-    # "created_at" : None,
-    # "updated_at" : None,
+    "user_uid":None,
+    # "postcode":None,
+    # "created_at":None,
+    # "updated_at":None,
     # "deleted_at" : None
     }
     def get(self):
@@ -380,20 +381,21 @@ class DimDates:
     """
     def __init__(self) -> None:
         self.Item = {
-    "transaction_date" : None,# validated or updated
-    "day_of_month" : None,
-    "month_of_year" : None,
-    "month_name"  : None,
-    "year" : None,
-    "week_of_month" : None,
-    "quarter_of_year" : None,
-    # "created_at" : None,
-    # "updated_at" : None,
+    "transaction_date":None,# validated or updated
+    "day_of_month":None,
+    "month_of_year":None,
+    "month_name": None,
+    "year":None,
+    "week_of_month":None,
+    "quarter_of_year":None,
+    # "created_at":None,
+    # "updated_at":None,
     # "deleted_at" : None
     }
     def get(self):
         return self.Item
 
+# fix
 class FactTransactions:
 
     def __init__(self) -> None:
@@ -408,6 +410,7 @@ class FactTransactions:
     def get(self):
         return self.Item
 
+
 # MongoDB History Facts
 class TransactionFact:
     """
@@ -466,8 +469,8 @@ class PreCategorized:
             "frequency_uid": None, # ID de la frecuencia asociada a la transacción
             "is_essential": None, # True| False  si el gasto es escencial
             "is_membership": None, # True| False si el gasto pertence a un menbresía
-            "income_source_uid" : None,
-            "is_loan_received" : None,
+            "income_source_uid":None,
+            "is_loan_received":None,
             "is_loan_requested": None,
             "status": None,
             "categorized": None,
@@ -680,8 +683,8 @@ class ItemTrans:
     def get(self):
         return self.Item
 
-# Diccionarios
-class Transaction_:
+# Dims Diccionarios
+class Transaction_Map_DWH:
 
     def __init__(self) -> None:
 
@@ -760,4 +763,43 @@ class Transaction_:
             }
     
     def get(self):
-        return self.Item
\ No newline at end of file
+        return self.Item
+    
+class Visualization_Map_DWH:
+
+    def __init__(self) -> None:
+
+        self.Item = {
+        'transaction_uid':None,
+        'language_code':None,
+        'country_code': None,
+        'flow_type':None,
+        'message_type': None,
+        'validated':None,
+        'source_description': None,
+        'clean_description':None,
+        'is_loan_requested': None,
+        'is_membership':None,
+        'subcategory_uid': None,
+        'category_uid': None,
+        'special_moment_uid': None,
+        'is_essential':None,
+        'frequency_uid': None,
+        'asset_uid': None,
+        'person_uid': None,
+        'business_uid':None,
+        'income_source_uid': None,
+        'is_loan_received': None,
+        'description': None,
+        'original_created_date':None,
+        'created_at_homologation': None,
+        'classified_at': None,
+        'created_at': None, #validate ()
+        'updated_at': None, #update expense or income 
+        }
+    
+    def get(self):
+        return self.Item
+
+
+    
\ No newline at end of file
