@@ -320,18 +320,12 @@ for col in sorted(r.columns.tolist()):
 
     
 #r[cols].set_index(['nickname_def_usr','category_uid_def_algo']).apply(pd.Series.explode).reset_index()
-# .sort_values(by=['created_at_head'], ascending = False)
-print("shape: ", r.shape)
 
 r.replace(np.nan, None, inplace=True)
 r.replace(pd.NaT, None, inplace=True)
 tmp = {'created_at_homologation': pd.NaT}
 
-
-
 for idx ,item in enumerate(r.to_dict(orient='records')):
-    print(idx, "user_uid:",item['user_uid'],"\n transaction_uid:",item['transaction_uid'])
-    print("... ")
     if 'classification_datetime' in item:
         item['classified_at'] = item['classification_datetime']
 
@@ -340,28 +334,20 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     else :
         item['language_code'] = 'es-MX'
     
-    
     response = get_info_by_transaction_uid(item['transaction_uid'])
     
     if response is None :
         continue 
-    
-    print("response: ",response)
-    print("+++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
-    print("item: ", item)
+
     # Dict to necessary data
     transaction_dict = Transaction_().get()
     transaction_dict.update(item)
     
     transaction_dict.update(response)
-    
-
 
     if transaction_dict['clean_description'] is None:
         transaction_dict['clean_description'] = ''
 
-
-
     if transaction_dict['model_classification_version'] is None:
         transaction_dict['model_classification_version'] = 'bf24e9bff6ac4750b1daab8cd57f396d'
 
@@ -374,10 +360,8 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     if transaction_dict['model_collective_version'] is None:
         transaction_dict['model_collective_version'] = '7Sdt1KJFB4DVVV4kqnSO5AEMVJF66q9ASUAAJG'
 
-        
     format_inter = '%Y-%m-%dT%H:%M:%S'
     
-    
     if not transaction_dict['created_at_homologation'] or transaction_dict['created_at_homologation'] is pd.NaT:
         transaction_dict['created_at_homologation'] = datetime.strptime('2023-01-01T00:00:00',format_inter).replace(microsecond=0).isoformat()
         
@@ -391,7 +375,6 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     if not transaction_dict['created_at']:
         transaction_dict['created_at'] = datetime.strptime('2023-01-01T00:00:00',format_inter).replace(microsecond=0).isoformat()
         
-
     keys = Transaction_().get().keys()
 
     rm_list = list()
@@ -426,16 +409,6 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
                     }
     
         RedShift.insert_dim_account(dict_values = account_dict)
-    
-        print("****************************************\n")
-        print(account_dict)
-        print("****************************************\n")
-        print(user_dict)
-        print("****************************************\n")
-        
-    print(transaction_dict)
-    print("****************************************\n")
-
 
     date_dict = RedShift.date_descomposition(str(response['collected_at']).replace(" ","T").split(".")[0])
     table_name = 'dim_dates'
@@ -444,7 +417,6 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     if not RedShift.exists(table_name,column_name ,value = str(date_dict['transaction_date']) ):
         RedShift.insert_dim_dates(dict_values = date_dict)
 
-
     fact_transactions_dict = dict ()
     fact_transactions_dict['transaction_date'] = str(date_dict['transaction_date'])
     fact_transactions_dict['transaction_uid'] = item['transaction_uid']
@@ -453,18 +425,8 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     fact_transactions_dict['amount'] = response['amount']
     fact_transactions_dict['currency'] = response['currency']
 
-
- 
-    print("\n\nfact_transactions_dict: ")
-    print(fact_transactions_dict)
-    print("----------------------------------------------")
-
     # Validación o updated de una transacción 
     # poner la bandera de Categorización automática
     RedShift.insert_dim_transaction(dict_values = transaction_dict)
 
-    RedShift.insert_fact_transactions(dict_values = fact_transactions_dict)
-    
-    print("+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
-    print("+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
-    
\ No newline at end of file
+    RedShift.insert_fact_transactions(dict_values = fact_transactions_dict)
\ No newline at end of file
